/* spgs.h
 *
 * Copyright 2001, 2002 Sun Microsystems, Inc.,
 * Copyright 2001, 2002 BAUM Retec, A.G.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __SPGS_H__
#define __SPGS_H__

#include <libbonobo.h>
#include <gnome-speech/gnome-speech.h>

#include "srspeech.h"

void	gs_say		(SRSVoice	*voice, 
			 const char 	*string);
void 	gs_shut_up   	(void);
void 	gs_pause     	(void);
void 	gs_resume    	(void);

int  	gs_init      	(TTSEngine 	*engine);
void 	gs_terminate	(void);


#endif /* __SPGS_H__ */
